@@ -8,10 +8,10 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.assets._jsii
 import aws_cdk.aws_batch._jsii
 import aws_cdk.aws_cloudwatch._jsii
 import aws_cdk.aws_codebuild._jsii
+import aws_cdk.aws_databrew._jsii
 import aws_cdk.aws_dynamodb._jsii
 import aws_cdk.aws_ec2._jsii
 import aws_cdk.aws_ecr._jsii
@@ -30,9 +30,9 @@ import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
     "@aws-cdk/aws-stepfunctions-tasks",
-    "1.83.0",
+    "1.88.0",
     __name__[0:-6],
-    "aws-stepfunctions-tasks@1.83.0.jsii.tgz",
+    "aws-stepfunctions-tasks@1.88.0.jsii.tgz",
 )
 
 __all__ = [
